"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WXACode = void 0;
/**
 * 小程序码
 * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/qr-code/wxacode.createQRCode.html
 */
class WXACode {
    constructor(mini) {
        this.mini = mini;
    }
    /**
     * 生成小程序码接口 A
     * 可接受 path 参数较长，生成个数受限，请谨慎使用
     * 接口 A 加上接口 C，总共生成的码数量限制为 100,000，请谨慎调用。
     */
    createQRCode(path, width = 430) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/wxaapp/createwxaqrcode";
            const body = {
                path,
                width
            };
            const resp = yield this.mini.http.post(url, body, {
                responseType: "arraybuffer"
            });
            if (resp.headers["content-type"].startsWith("application/json")) {
                const data = JSON.parse(resp.data.toString());
                if (data.errcode) {
                    throw new Error(`生成小程序码接口A调用失败: ${JSON.stringify(data)}`);
                }
            }
            return resp.data;
        });
    }
    /**
     * 生成小程序码接口 C
     * 生成二维码，可接受 path 参数较长，生成个数受限
     */
    get({ path, width = 430, auto_color = false, line_color = { r: 0, g: 0, b: 0 }, is_hyaline = false }) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/wxaapp/getwxacode";
            const body = {
                path,
                width,
                auto_color,
                line_color,
                is_hyaline
            };
            const resp = yield this.mini.http.post(url, body, {
                responseType: "arraybuffer"
            });
            if (resp.headers["content-type"].startsWith("application/json")) {
                const data = JSON.parse(resp.data.toString());
                if (data.errcode) {
                    throw new Error(`生成小程序码接口C调用失败: ${JSON.stringify(data)}`);
                }
            }
            return resp.data;
        });
    }
    /**
     * 生成小程序码接口 B
     * 适用于需要的码数量极多的业务场景。通过该接口生成的小程序码，永久有效，数量暂无限制。
     */
    getUnlimited({ scene, page = null, width = 430, auto_color = false, line_color = { r: 0, g: 0, b: 0 }, is_hyaline = false }) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "wxa/getwxacodeunlimit";
            const body = {
                scene,
                page,
                width,
                auto_color,
                line_color,
                is_hyaline
            };
            const resp = yield this.mini.http.post(url, body, {
                responseType: "arraybuffer"
            });
            if (resp.headers["content-type"].startsWith("application/json")) {
                const data = JSON.parse(resp.data.toString());
                if (data.errcode) {
                    throw new Error(`生成小程序码接口B调用失败: ${JSON.stringify(data)}`);
                }
            }
            return resp.data;
        });
    }
}
exports.WXACode = WXACode;
