"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Jssdk = void 0;
const crypto = require("crypto");
/**
 * JSSDK 管理
 * https://developers.weixin.qq.com/doc/offiaccount/OA_Web_Apps/JS-SDK.html
 */
class Jssdk {
    constructor(oa) {
        this.oa = oa;
    }
    /**
     * JSSDK Config
     * https://mp.weixin.qq.com/wiki?t=resource/res_main&id=mp1421141115
     * @param url
     */
    getJsapiConfig(url, jsApiList, debug = false) {
        return __awaiter(this, void 0, void 0, function* () {
            const nonceStr = Math.random()
                .toString(36)
                .substring(2, 15);
            const timestamp = Math.floor(+new Date() / 1000);
            const jsapiTicket = yield this.getJsapiTicket();
            const params = [
                ["noncestr", nonceStr],
                ["timestamp", timestamp],
                ["jsapi_ticket", jsapiTicket],
                ["url", url]
            ];
            const signature = crypto
                .createHash("sha1")
                .update(params
                .map(e => e.join("="))
                .sort()
                .join("&"), "utf8")
                .digest("hex");
            return {
                appId: this.oa.config.appId,
                jsApiList,
                debug,
                nonceStr,
                timestamp,
                signature
            };
        });
    }
    getJsapiTicket() {
        return __awaiter(this, void 0, void 0, function* () {
            const key = `appid:${this.oa.config.appId}:jssdk`;
            let ticket = yield this.oa.storage.get(key);
            if (!ticket) {
                const jsapiTicket = yield this.getJsapiTicketFromServer();
                ticket = jsapiTicket.ticket;
                this.oa.storage.set(key, ticket, jsapiTicket.expires_in - 60 * 30);
            }
            return ticket;
        });
    }
    /**
     * 获取 jsapi_ticket
     * https://mp.weixin.qq.com/wiki?t=resource/res_main&id=mp1421141115
     */
    getJsapiTicketFromServer() {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `cgi-bin/ticket/getticket`;
            const params = { type: "jsapi" };
            const resp = yield this.oa.http.get(url, { params });
            if (resp.data.errcode) {
                throw new Error(`获取 jsapi_ticket 失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
}
exports.Jssdk = Jssdk;
