"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MPServer = void 0;
const crypto_1 = require("crypto");
const xml2js = require("xml2js");
const encrypt = (algorithm, content) => {
    const hash = crypto_1.createHash(algorithm);
    hash.update(content);
    return hash.digest("hex");
};
const sha1 = (content) => encrypt("sha1", content);
const buildXml = (message) => {
    const builder = new xml2js.Builder({ rootName: "xml" });
    return builder.buildObject(message);
};
/**
 * 返回 Connect 中间件
 */
class MPServer {
    constructor(oa) {
        this.oa = oa;
    }
    /**
     * 回显
     * https://mp.weixin.qq.com/wiki?t=resource/res_main&id=mp1472017492_58YV5
     */
    echo() {
        return (req, res) => {
            const { signature, timestamp, echostr, nonce } = req.query;
            const arr = [this.oa.config.token, timestamp, nonce];
            arr.sort();
            const sha = sha1(arr.join(""));
            const result = signature === sha ? echostr : "Invalid Signature";
            res.send(result);
        };
    }
    /**
     * 监听微信消息
     */
    listen(routers) {
        return (req, res) => __awaiter(this, void 0, void 0, function* () {
            const body = req.body;
            const { xml } = yield xml2js.parseStringPromise(body);
            const msg = Object.keys(xml).reduce((p, c) => {
                p[c] = xml[c][0];
                return p;
            }, {});
            const asyncTasks = routers
                .filter(router => {
                if (router.msgType !== msg.MsgType)
                    return false;
                if (router.event && router.event !== msg.Event)
                    return false;
                if (router.eventKey &&
                    router.eventKey !== msg.EventKey)
                    return false;
                if (router.textContentRegExp &&
                    !router.textContentRegExp.test(msg.Content)) {
                    return false;
                }
                return true;
            })
                .map(router => router.processor(msg));
            const content = (yield Promise.all(asyncTasks))
                .filter(e => e && e !== "")
                .join("\n");
            const result = content
                ? buildXml({
                    CreateTime: Math.floor(+new Date() / 1000),
                    ToUserName: msg.FromUserName,
                    FromUserName: msg.ToUserName,
                    MsgType: "text",
                    Content: content
                })
                : "success";
            res.send(result);
        });
    }
}
exports.MPServer = MPServer;
