import { OfficialAccount } from "../";
import { IUserInfo, IOpenIdPagination, ITags, ITag } from "./interface";
/**
 * 用户管理
 */
export declare class User {
    private oa;
    constructor(oa: OfficialAccount);
    /**
     * 获取用户列表
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/Get_users_basic_information_UnionID.html#UinonId
     */
    list(next_openid?: string): Promise<IOpenIdPagination>;
    /**
     * 通过 Open ID 获取用户基本信息(UnionID机制)
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/Get_users_basic_information_UnionID.html#UinonId
     */
    get({ openid, lang }: {
        openid: any;
        lang?: string;
    }): Promise<IUserInfo>;
    /**
     * 批量获取用户基本信息
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/Get_users_basic_information_UnionID.html#UinonId
     */
    batchget({ openids, lang }: {
        openids: string[];
        lang?: string;
    }): Promise<IUserInfo[]>;
    /**
     * 设置用户备注名
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/Configuring_user_notes.html
     */
    remark({ openid, remark }: {
        openid: string;
        remark: string;
    }): Promise<string>;
    /**
     * 获取公众号的黑名单列表
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/Manage_blacklist.html
     */
    blacklist(begin_openid?: string): Promise<IOpenIdPagination>;
    /**
     * 拉黑用户
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/Manage_blacklist.html
     */
    block(openid_list?: string[]): Promise<string>;
    /**
     * 取消拉黑用户
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/Manage_blacklist.html
     */
    unblock(openid_list?: string[]): Promise<string>;
    /**
     * 创建标签
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/User_Tag_Management.html
     */
    createTag(name: string): Promise<ITag>;
    /**
     * 编辑标签
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/User_Tag_Management.html
     */
    updateTag(id: number, name: string): Promise<string>;
    /**
     * 删除标签
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/User_Tag_Management.html
     */
    deleteTag(id: number): Promise<string>;
    /**
     * 获取公众号已创建的标签
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/User_Tag_Management.html
     */
    listTag(): Promise<ITags>;
    /**
     * 获取标签下粉丝列表
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/User_Tag_Management.html
     */
    usersOfTag(tagid: number, next_openid?: string): Promise<IOpenIdPagination>;
    /**
     * 批量为用户打标签
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/User_Tag_Management.html
     */
    tagUsers(tagid: number, openid_list: string[]): Promise<string>;
    /**
     * 批量为用户取消标签
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/User_Tag_Management.html
     */
    untagUsers(tagid: number, openid_list: string[]): Promise<string>;
    /**
     * 获取用户身上的标签列表
     * https://developers.weixin.qq.com/doc/offiaccount/User_Management/User_Tag_Management.html
     */
    userTags(openid: string): Promise<number[]>;
}
